@@ -145,11 +145,6 @@ hurdlemsm.fit <- function(
       ncats = ncol(classprob)
       newY = apply(classprob[,], 1, function(x) -1+which.max(rmultinom(1, 1, x)))
     }
-    #if(msmcontrol$predmethod=="expected"){
-    #  pmfg0 = predict(fit, newdata = newdata, type="count")
-    #  pmf0  = predict(fit, newdata = newdata, type="zero")
-    #  newY = rbinom(MCsize, 1, 1-pmf0)*(pmfg0)
-    #}
     newY
   }
   newids <- data.frame(temp=sort(sample(unique(qdata[,id, drop=TRUE]), MCsize, 
@@ -166,15 +161,13 @@ hurdlemsm.fit <- function(
   msmdat$Ya = do.call("c", predmat)
   msmdat$psi = rep(intvals, each=MCsize)
   
-  fstr = paste("Ya ~ 1", 
+  msmforms = paste("Ya ~ 1", 
                ifelse(containmix[["count"]], "+ poly(psi, degree=degree, raw=TRUE) | 1", "| 1"),
                ifelse(containmix[["zero"]], "+ poly(psi, degree=degree, raw=TRUE)", "")
   )
-  #if(!is.null(weights)){
-  #  msmdat[,'__weights'] = newdata[,weights]
-  #}
-
-  msmfit <- hurdle(as.formula(fstr), data=msmdat, x=x,
+  msmform = as.formula(msmforms)
+  
+  msmfit <- hurdle(as.formula(msmform), data=msmdat, x=x,
                      weights=weights,
                      ...)
   #if(msmfit$optim$convergence[1]!=0) warning("MSM did not converge")
@@ -372,7 +365,7 @@ qgcomp.hurdle.noboot <- function(f,
 
   qx <- qdata[, expnms]
   names(qx) <- paste0(names(qx), "_q")
-  res <- list(
+  res <- .qgcomp_object(
     qx = qx, fit = fit, 
     psi = lapply(estb, function(x) x[-1]), 
     var.psi = lapply(seb, function(x) x[-1]^2), 
@@ -392,8 +385,6 @@ qgcomp.hurdle.noboot <- function(f,
     neg.weights = lapply(neg.weights, function(x) sort(x, decreasing = TRUE)), 
     pos.size = pos.size,
     neg.size = neg.size,
-    bootstrap=FALSE,
-    cov.yhat=NULL,
     alpha=alpha, call=origcall
   )
   #if(fit$family$family=='gaussian'){
@@ -405,26 +396,29 @@ qgcomp.hurdle.noboot <- function(f,
     res$zstat <- tstat
     res$pval <- pvalz
   #}
-    attr(res, "class") <- c("ziqgcompfit", "qgcompfit")
+    attr(res, "class") <- c("ziqgcompfit", attr(res, "class"))
     res
 }
 
-qgcomp.hurdle.boot <- function(f, 
-                           data, 
-                           expnms=NULL, 
-                           q=4, 
-                           breaks=NULL, 
-                           id=NULL,
-                           weights,
-                           alpha=0.05, 
-                           B=200, 
-                           degree=1, 
-                           seed=NULL, 
-                           bayes=FALSE, 
-                           parallel=FALSE, 
-                           MCsize=10000, 
-                           msmcontrol=hurdlemsm.fit.control(),
-                          ...){
+qgcomp.hurdle.boot <- function(
+ f, 
+ data, 
+ expnms=NULL, 
+ q=4, 
+ breaks=NULL, 
+ id=NULL,
+ weights,
+ alpha=0.05, 
+ B=200, 
+ degree=1, 
+ seed=NULL, 
+ bayes=FALSE, 
+ parallel=FALSE, 
+ MCsize=10000, 
+ msmcontrol=hurdlemsm.fit.control(),
+ parplan = FALSE,
+ ...
+){
   #' @title Quantile g-computation for hurdle count outcomes
   #'  
   #' @description This function estimates a linear dose-response parameter representing a one quantile
@@ -497,6 +491,7 @@ qgcomp.hurdle.boot <- function(f,
   #'  linear fits with qgcomp.hurdle.noboot to gain some intuition for the level of expected simulation 
   #'  error at a given value of MCsize)
   #' @param msmcontrol named list from \code{\link[qgcomp]{hurdlemsm.fit.control}}
+  #' @param parplan (logical, default=FALSE) automatically set future::plan to plan(multiprocess) (and set to plan(invisible) after bootstrapping)
   #' @param ... arguments to glm (e.g. family)
   #' @seealso \code{\link[qgcomp]{qgcomp.hurdle.noboot}},\code{\link[qgcomp]{qgcomp.boot}}, 
   #' \code{\link[qgcomp]{qgcomp.cox.boot}},  and \code{\link[pscl]{hurdle}}
@@ -557,7 +552,7 @@ qgcomp.hurdle.boot <- function(f,
   message("qgcomp.hurdle.boot function is still experimental. Please use with caution and be sure results are reasonable.\n")      
   # list containers
   estb <- vcov_mod <- seb <- tstat <- pvalz <- allterms <- containmix  <- ci <- tstat<- list() 
-  pos.weights <- neg.weights <- pos.psi <- neg.psi <- pos.size <- neg.size <- NULL
+  #pos.weights <- neg.weights <- pos.psi <- neg.psi <- pos.size <- neg.size <- NULL
   suppressWarnings(testfit <- hurdle(f, data = data, control=hurdle.control(maxit = 1, EM=FALSE)))
   allterms$count = attr(terms(testfit, "count"), "term.labels")
   allterms$zero = attr(terms(testfit, "zero"), "term.labels")
@@ -677,7 +672,7 @@ qgcomp.hurdle.boot <- function(f,
   set.seed(seed)
   if(parallel){
     #Sys.setenv(R_FUTURE_SUPPORTSMULTICORE_UNSTABLE="quiet")
-    future::plan(strategy = future::multisession)
+    if(parplan) future::plan(strategy = future::multisession)
     #testenv <- list2env(list(qdata=qdata, weights=weights))
     bootsamps <- future.apply::future_lapply(X=seq_len(B), FUN=psi.only,f=newform, qdata=qdata, intvals=intvals, 
                                              expnms=expnms, degree=degree, nids=nids, id=id, 
@@ -686,7 +681,7 @@ qgcomp.hurdle.boot <- function(f,
                                              future.seed=TRUE,
                                              ...)
     
-    future::plan(strategy = future::transparent)
+    if(parplan) future::plan(strategy = future::transparent)
   }else{
     bootsamps <- lapply(X=seq_len(B), FUN=psi.only,f=newform, qdata=qdata, intvals=intvals, 
                         expnms=expnms, degree=degree, nids=nids, id=id, 
@@ -713,7 +708,7 @@ qgcomp.hurdle.boot <- function(f,
   
   qx <- qdata[, expnms]
   names(qx) <- paste0(names(qx), "_q")
-  res <- list(
+  res <- .qgcomp_object(
     qx = qx, fit = msmfit$fit, msmfit = msmfit$msmfit, 
     psi = lapply(estb, function(x) x[-1]), 
     var.psi = lapply(seb, function(x) x[-1]^2), 
@@ -724,12 +719,6 @@ qgcomp.hurdle.boot <- function(f,
     covmat.coef=vcov_mod,
     ci.coef = ci,
     expnms=expnms, q=q, breaks=br, degree=degree,
-    pos.psi = pos.psi, 
-    neg.psi = neg.psi,
-    pos.weights = lapply(pos.weights, function(x) sort(x, decreasing = TRUE)),
-    neg.weights = lapply(neg.weights, function(x) sort(x, decreasing = TRUE)), 
-    pos.size = pos.size,
-    neg.size = neg.size,
     bootstrap=TRUE,
     cov.yhat=cov.yhat,
     y.expected=msmfit$Ya, y.expectedmsm=msmfit$Yamsm, index=msmfit$A,
@@ -738,7 +727,7 @@ qgcomp.hurdle.boot <- function(f,
   )
   res$zstat <- tstat
   res$pval <- pvalz
-  attr(res, "class") <- c("ziqgcompfit", "qgcompfit")
+  attr(res, "class") <- c("ziqgcompfit", attr(res, "class"))
   res
 }
 
